@@ -1,6 +1,6 @@
 from .base import BackendBase
-from .qiniu import Qiniu
-from .yaocdn import YaoStorage
+from .bk_qiniu import Qiniu
+from .bk_yaocdn import YaoStorage
 
 backend_factory = {
     'qiniu': Qiniu,
