@@ -63,9 +63,10 @@ class Client(Singleton):
         self._inited = True
 
     def get_qiniu_token(self, fname):
-        qiniu_backend_keys = [k for k in list(self.backend_pools.keys) if k.startswith('qiniu')]
+        qiniu_backend_keys = [k for k in list(self.backend_pools.keys()) if k.startswith('qiniu')]
         if len(qiniu_backend_keys):
-            backend = random.random(qiniu_backend_keys)[0]
+            backend_key = random.sample(qiniu_backend_keys, 1)[0]
+            backend = self.backend_pools[backend_key]
             return backend.get_token(fname)
         return None
     
